%% Calculation Parameters
solute = 'Sucrose'; % Select either Sucrose, Citric, or Shkimic
RHi = 0.2; %Initial RH
RHf = 0.5; %Final RH
s0 = 1000e-9; %Initial Radius in m
T = 298; %Temperature
Nmax = 1000; % Number of eigenfunctions used in expansion
%% Selecting Solute
if strcmp(solute,'Sucrose')
    mb = 342.30 / 1000;
    actfun = @(wB) ActivitySucrose(wB,T);
    rhofun = @(wB) DensitySucrose(wB);
    difffun = @(aw) DiffusivitySucrose(aw,T);
elseif strcmp(solute,'Citric')
    mb = 192.124 / 1000;
    actfun = @(wB) ActivityCitric(wB,T);
    rhofun = @(wB) DensityCitric(wB);
    difffun = @(aw) DiffusivityCitric(aw);    
elseif strcmp(solute,'Shikimic')
    mb = 174.15 / 1000;
    actfun = @(wB) ActivityShikimic(wB);
    rhofun = @(wB) DensityShikimic(wB);
    difffun = @(wB) DiffusivityShikimic(wB,T);   
end
%%
%% Droplet Properties
%Weight Fractions of Sucrose
wi = fzero(@(wB) actfun(wB)-RHi, [0,1]);
wf = fzero(@(wB) actfun(wB)-RHf, [0,1]);
%Densities of Suctose
rhoi = rhofun(wi);
rhof = rhofun(wf);
rhomean = (rhoi + rhof) / 2; 
%Mass Concentrations of Water
rhoAi = rhoi*(1-wi);
rhoAf = rhof *(1-wf);
rhoAmean = (rhoAi + rhoAf) / 2;
wmean = 1 - rhoAmean / rhomean;
%% Find Alpha
% Getting rhow as a function of rhoA
w = (0:0.01:1)';
rhodat = rhofun(w);
rhoAdat = (1-w).*rhodat;
rhofull = fit(rhoAdat,rhodat,'poly4');
alpha = differentiate(rhofull,rhoAmean);
rholin = rhomean + alpha*(rhoAdat - rhoAmean);
rhoApoints = [rhoAi,rhoAmean,rhoAf];
rhopoints = rhofull(rhoApoints);
figure
plot(rhofull,'.')
hold on
plot(rhoAdat,rholin)
hold on
plot(rhoApoints,rhopoints,'.','MarkerSize',15)
ylabel('Density of Droplet (kg/m^3)')
xlabel ('Mass Concentration of Water (kg/m^3)')
%% 
ma = 18.015 / 1000; % Water
%Epsilon Calc
epsilon = ((alpha*rhoAmean) - rhomean) / (alpha - 1);
% Activity Coeff
awf = RHf;
xf = ((rhoAf / ma) / ((rhoAf / ma) + (rhof - rhoAf)/mb));
gammaf = awf / xf;
%% Weight Function
R = 8.3144598;
gammamin = 0.35;
rhocut = rhoAi + (gammamin*(rhoAf - rhoAi));
normfun = @(rhoA) rhoA.^0;
norm = integral(normfun,rhocut,rhoAf);
fun = @(RhoA) Beta0integrand(RhoA,rhofull(RhoA)',rhomean,rhoAmean,alpha,mb,actfun,difffun,solute);
beta0 = (1/norm)*(integral(fun,rhocut,rhoAf));
k = ((ma^2)*mb*gammaf*VapourPressureWat(T)*((rhomean - (alpha*rhoAmean)))) / ...
   (R*T*((ma*((alpha-1)*rhoAf-alpha*rhoAmean+rhomean)+mb*rhoAf)^2));
%% Equation for s
n = (1:1:Nmax)';
kappa = DiffusivityWaterVap(T)*k/beta0;
ksi = 1-kappa;
g = @(x) x*cot(x) - ksi;
lambda = zeros(size(n));
for i = 1:size(n,1)
    lambda(i) = fzero(g,n(i)*pi-1e-9);
end
B = ((((lambda).^2)+(ksi^2)).*sin(lambda))./ ((lambda.^2).*((lambda.^2)+(ksi*(ksi-1))));
t1 = (s0^2)/(beta0*((lambda(1))^2));
tau = 0.55*t1;
% Final Radius
sinfinity = s0*(((epsilon - rhoAi)/(epsilon - rhoAf))^(1/3));
coeffa = (B ./ (lambda.^2)) .* sin(lambda);
coeffc = -((beta0).*((lambda).^2)) / (s0^2);
% mint
t = (0:tau/100:8*tau)';
analyticdat = zeros(size(t));
for i = 1:size(analyticdat,1)
    ti = t(i);
    sumterm = sum(coeffa.*exp(coeffc.*ti));
    analyticdat(i) = (-(((epsilon - rhoAi)*(s0^3)) /...
    (rhoAf+(6*(kappa^2)*(rhoAi - rhoAf)*sumterm)-epsilon))) ^ (1/3);
end
radiusdat = analyticdat .* 1e9;
radiusfinal = sinfinity .*1e9; 
figure
plot(t,radiusdat, '.')
xlabel('Time (s)')
ylabel('Radius (nm)')
hold on
plot(t,radiusfinal, 'r.')
%% Characteristic Time
if s0 > sinfinity
    taus = ( 1 / exp(1));
    smin = sinfinity;
    smax = s0;
else 
    taus = 1 - ( 1 / exp(1));
    smin = s0;
    smax = sinfinity;
end
normdat = ((analyticdat) - smin) ./ (smax - smin);
diffs = abs(normdat - taus);
nearest = diffs == min(diffs);
tauaplot = t(nearest);
y = taus*ones(size(t));
x = 0:0.01:1;
w = tauaplot*ones(size(x));
figure
plot(t,normdat)
string = strcat('\tau = ', num2str(tau), 's');
annotation('textbox','String',string,'FitBoxToText','on');
xlabel(' Time(s) ')
ylabel(' Dimensionless Radius ')
hold on
plot(t,y)
hold on
plot(w,x)